@@ -18,9 +18,12 @@ Drivers for working with different providers
 """
 
 __all__ = [
+    'brightbox',
     'dummy',
     'ec2',
     'ecp',
+    'elastichosts',
+    'cloudsigma',
     'gogrid',
     'ibm_sbc',
     'linode',
@@ -31,5 +34,5 @@ __all__ = [
     'softlayer',
     'vcloud',
     'voxel',
-    'vpsnet',
+    'vpsnet'
 ]
